@@ -10,7 +10,17 @@ import math
 import os
 import sys
 from pathlib import Path
-from typing import Any, Callable, Iterable, Iterator, Sequence, Tuple, TypeVar, overload
+from typing import (
+    Any,
+    Callable,
+    Generic,
+    Iterable,
+    Iterator,
+    Sequence,
+    Tuple,
+    TypeVar,
+    overload,
+)
 from weakref import ref
 
 from docstring_parser import DocstringParam, parse
@@ -27,6 +37,7 @@ from ._bases import (
     CategoricalWidget,
     ContainerWidget,
     MainWindowWidget,
+    MultiValuedSliderWidget,
     RangedWidget,
     SliderWidget,
     TransformedRangedWidget,
@@ -298,6 +309,16 @@ class FloatSlider(SliderWidget):
     """A slider widget to adjust an integer value within a range."""
 
 
+@backend_widget
+class RangeSlider(MultiValuedSliderWidget):
+    """A slider widget to adjust a range between two integer values within a range."""
+
+
+@backend_widget
+class FloatRangeSlider(MultiValuedSliderWidget):
+    """A slider widget to adjust a range defined by two float values within a range."""
+
+
 @merge_super_sigs
 class LogSlider(TransformedRangedWidget):
     """A slider widget to adjust a numerical value logarithmically within a range.
@@ -608,7 +629,7 @@ class RangeEdit(Container):
 
 
 class SliceEdit(RangeEdit):
-    """A widget to represent range objects, with start/stop/step.
+    """A widget to represent `slice` objects, with start/stop/step.
 
     slice(stop)
     slice(start, stop[, step])
@@ -617,7 +638,7 @@ class SliceEdit(RangeEdit):
     """
 
     @property  # type: ignore
-    def value(self) -> slice:  # type: ignore
+    def value(self) -> slice:
         """Return current value of the widget.  This may be interpreted by backends."""
         return slice(self.start.value, self.stop.value, self.step.value)
 
@@ -773,7 +794,7 @@ class ListEdit(Container):
             self._append_value(v)
 
     @property
-    def data(self) -> ListDataView:
+    def data(self) -> ListDataView[_V]:
         """Return a data view of current value."""
         return ListDataView(self)
 
@@ -784,7 +805,7 @@ class ListEdit(Container):
             self._append_value(v)
 
 
-class ListDataView:
+class ListDataView(Generic[_V]):
     """Data view of ListEdit."""
 
     def __init__(self, obj: ListEdit):
@@ -792,7 +813,7 @@ class ListDataView:
         self._widgets: list[ValueWidget] = list(obj[:-2])  # type: ignore
 
     def __repr__(self):
-        """A list-like representation."""
+        """Return list-like representation."""
         return f"{self.__class__.__name__}({list(self)!r})"
 
     def __len__(self):
